# Tutorials

Here are step-by-step guides to get you started.

<!-- --8<-- [start:tutorials] -->

=== card {: href=/tutorials/create-your-first-component/ }

    :fontawesome-regular-file-code:
    **Your first component**

    ---
    Learn the basics of composing a UI component with Pret.

=== card {: href=/tutorials/sharing-state/ }

    :fontawesome-solid-book:
    **Sharing state**

    ---
    Learn how to manage the state of your app and share it between multiple components.

=== card {: href=/tutorials/tictactoe/ }

    :fontawesome-regular-calendar:
    **Tic Tac Toe**

    ---
    Building what we have learned in the previous tutorials, let's build a Tic Tac Toe game.

=== card {: href=/tutorials/interacting-with-the-server/ }

    :fontawesome-regular-square-check:
    **Interacting with the server**

    ---
    Learn how to run server-side code and interact with the server from the client, and vice-versa.

<!-- --8<-- [end:tutorials] -->
